/** \file
 * \brief IUPLua5 GLControls internal Functions
 *
 * See Copyright Notice in "iup.h"
 */
 
#ifndef __IL_GLCONTROLS_H 
#define __IL_GLCONTROLS_H

#ifdef __cplusplus
extern "C" {
#endif

int iupglcanvasboxlua_open(lua_State * L);
int iupglsubcanvaslua_open(lua_State * L);
int iupgllabellua_open(lua_State * L);
int iupglbuttonlua_open(lua_State * L);
int iupglexpanderlua_open(lua_State * L);
int iupglframelua_open(lua_State * L);
int iupgllinklua_open(lua_State * L);
int iupglprogressbarlua_open(lua_State * L);
int iupglseparatorlua_open(lua_State * L);
int iupglsizeboxlua_open(lua_State * L);
int iupgltogglelua_open(lua_State * L);
int iupglvallua_open(lua_State * L); 
int iupglscrollboxlua_open(lua_State * L); 
int iupgltextlua_open(lua_State * L); 


#ifdef __cplusplus
}
#endif

#endif
